@@ -21,10 +21,10 @@ from CIDAN.LSSC.functions.progress_bar import printProgressBarFilter, printProgr
 from CIDAN.LSSC.functions.roi_extraction import roi_extract_image, combine_rois
 from CIDAN.LSSC.functions.roi_filter import filterRoiList
 from CIDAN.LSSC.functions.spatial_footprint import classify_components_ep
-from CIDAN.LSSC.functions.temporal_correlation import calculate_temporal_correlation
 from CIDAN.LSSC.process_data import process_data
 from CIDAN.TimeTrace.deltaFOverF import calculateDeltaFOverF
-from CIDAN.TimeTrace.mean import calculateMeanTrace
+from CIDAN.TimeTrace.mean import calculateMeanTrace, neuropil
+from CIDAN.TimeTrace.neuropil import calculate_nueropil
 from CIDAN.TimeTrace.waveletDenoise import waveletDenoise
 
 logger1 = logging.getLogger("CIDAN.DataHandler")
@@ -46,6 +46,40 @@ class DataHandler:
 
 
     """
+    # x is for roi data, y is for neuropil data, z is roi data denoised
+    time_trace_possibilities_functions = {
+        "Mean Florescence Denoised": lambda x, y, z: calculateMeanTrace(x, y, z,
+                                                                        denoise=True),
+        "Mean Florescence": lambda x, y, z: calculateMeanTrace(x, y, z, denoise=False),
+        "DeltaF Over F Denoised": lambda x, y, z: calculateDeltaFOverF(x, y, z,
+                                                                       denoise=True),
+        "DeltaF Over F": lambda x, y, z: calculateDeltaFOverF(x, y, z, denoise=False),
+        "Mean Floresence Denoised (Neuropil Corrected)": lambda x,
+                                                                y,
+                                                                z: calculateMeanTrace(x,
+                                                                                      y,
+                                                                                      z,
+                                                                                      denoise=True,
+                                                                                      sub_neuropil=True),
+        "Mean Floresence  (Neuropil Corrected)": lambda x, y, z: calculateMeanTrace(x,
+                                                                                    y,
+                                                                                    z,
+                                                                                    denoise=False,
+                                                                                    sub_neuropil=True),
+        "DeltaF Over F  (Neuropil Corrected)": lambda x, y, z: calculateDeltaFOverF(x,
+                                                                                    y,
+                                                                                    z,
+                                                                                    denoise=False,
+                                                                                    sub_neuropil=True),
+        "DeltaF Over F Denoised (Neuropil Corrected)": lambda x,
+                                                              y,
+                                                              z: calculateDeltaFOverF(x,
+                                                                                      y,
+                                                                                      z,
+                                                                                      denoise=True,
+                                                                                      sub_neuropil=True),
+        "Neuropil": lambda x, y, z: neuropil(x, y, z)
+    }
     _global_params_default = {
         "save_intermediate_steps": True,
         "need_recalc_dataset_params": True,
@@ -114,11 +148,11 @@ class DataHandler:
         "fill_holes": True,
         "refinement": True,
         "max_iter": 100,
-        "roi_circ_threshold": 20
+        "roi_circ_threshold": 20,
+
     }
     _time_trace_params_default = {
-        "time_trace_type": "Mean",
-        "denoise": True
+        "min_neuropil_pixels": 25
     }
 
     def __init__(self, data_path, save_dir_path, save_dir_already_created, trials=[],
@@ -147,7 +181,7 @@ class DataHandler:
                            (22, 132, 249), (224, 22, 249), (249, 22, 160)]
 
         self.save_dir_path = save_dir_path
-
+        self.time_trace_possibilities_functions = DataHandler.time_trace_possibilities_functions
         self.rois_loaded = False  # whether roi variables have been created
         if parameter_file:
             self.parameter_file_name = os.path.basename(parameter_file)
@@ -155,6 +189,10 @@ class DataHandler:
             self.create_new_save_dir()
             valid = self.load_param_json()
             self.global_params = DataHandler._global_params_default.copy()
+            if self.dataset_params["single_file_mode"]:
+                if not os.path.isdir(
+                        os.path.join(self.save_dir_path, "temp_files/dataset.zarr")):
+                    self.transform_data_to_zarr()
             # these indices are used for which trials to use for roi extract
             self._trials_loaded_indices = [num for num, x in enumerate(self.trials_all)
                                            if x in self.trials_loaded]
@@ -192,7 +230,7 @@ class DataHandler:
                     self.global_params["need_recalc_box_params"] = temp
             else:
                 temp = self.global_params["need_recalc_box_params"]
-                self.calculate_filters(auto_crop=True)
+                self.calculate_filters()
                 self.global_params["need_recalc_box_params"] = temp
             # if there are ROIs saved in the save dir load them and calculate time
             # traces
@@ -200,10 +238,11 @@ class DataHandler:
             if self.rois_exist:
                 try:
                     self.load_rois()
-                    self.calculate_time_traces()
+
                     self.rois_loaded = True
                 except:
                     print("ROI loading Failed")
+                self.calculate_time_traces()
             if not valid:
                 raise FileNotFoundError("Save directory not valid")
         else:
@@ -297,9 +336,10 @@ class DataHandler:
     @property
     def auto_crop(self):
         return self.dataset_params["auto_crop"]
+
     @property
     def rois_exist(self):
-        """
+        """ƒc
         Return if the roi save file exists
         """
         return not (self.global_params["need_recalc_eigen_params"] or
@@ -311,6 +351,7 @@ class DataHandler:
     @property
     def load_into_mem(self):
         return self.global_params["load_into_mem"]
+
     def load_rois(self):
         """
         Loads the ROIs if they exist and then generates the other variables associated
@@ -689,24 +730,23 @@ class DataHandler:
                                         'temp_files/%s.zarr' % self.trials_all[
                                             trial_num]), mode='w',
                            shape=cur_stack.shape,
-                           chunks=(32,128,128), dtype=np.float32)
+                           chunks=(32, 128, 128), dtype=np.float32)
             z1[:] = cur_stack
             if type(loaded_num) != bool:
                 self.mean_images[loaded_num] = np.mean(cur_stack, axis=0)
                 self.max_images[loaded_num] = np.max(cur_stack, axis=0)
-                self.temporal_correlation_images[
-                    loaded_num] = calculate_temporal_correlation(cur_stack).compute()
+                # self.temporal_correlation_images[
+                #     loaded_num] = calculate_temporal_correlation(cur_stack).compute()
 
 
         else:
 
-
             if type(loaded_num) != bool:
                 self.mean_images[loaded_num] = np.mean(cur_stack, axis=0)
                 self.max_images[loaded_num] = np.max(cur_stack, axis=0)
-                self.temporal_correlation_images[
-                    loaded_num] = calculate_temporal_correlation(
-                    cur_stack).compute()
+                # self.temporal_correlation_images[
+                #     loaded_num] = calculate_temporal_correlation(
+                #     cur_stack).compute()
         if self.filter_params["pca"] and type(loaded_num) != bool:
             pca = applyPCA(cur_stack, self.filter_params["pca_threshold"])
             if self.load_into_mem:
@@ -741,7 +781,8 @@ class DataHandler:
         -------
         A list of filtered trials
         """
-        self.dataset_params["auto_crop"] = auto_crop
+        if not self.auto_crop:
+            self.dataset_params["auto_crop"] = auto_crop
         if self.global_params["need_recalc_filter_params"] or self.global_params[
             "need_recalc_dataset_params"] or \
                 not hasattr(self, "dataset_trials_filtered"):
@@ -763,7 +804,7 @@ class DataHandler:
                 total_num_spatial_boxes=self.box_params["total_num_spatial_boxes"],
                 total_num_time_steps=self.box_params["total_num_time_steps"],
                 save_dir=self.save_dir_path, progress_signal=self.progress_signal)
-            if auto_crop:
+            if self.auto_crop:
                 self.suggested_crops = [[[0, 0], [0, 0]] for _ in self.trials_all]
             self.dataset_trials_filtered = [False] * len(self.trials_all)
             if self.filter_params["pca"]:
@@ -775,8 +816,10 @@ class DataHandler:
                 self._trials_loaded_indices)
             if not self.load_into_mem:
                 for num, trial_num in enumerate(self._trials_loaded_indices):
-                    self.dataset_trials_filtered[trial_num] = self.load_trial_filter_step(
-                        trial_num, self.load_trial_dataset_step(trial_num), loaded_num = num)
+                    self.dataset_trials_filtered[
+                        trial_num] = self.load_trial_filter_step(
+                        trial_num, self.load_trial_dataset_step(trial_num),
+                        loaded_num=num)
                     if num % 3 == 0:
                         self.dataset_trials_filtered = list(
                             dask.compute(*self.dataset_trials_filtered))
@@ -785,8 +828,13 @@ class DataHandler:
                     dask.compute(*self.dataset_trials_filtered))
             else:
                 for num, trial_num in enumerate(self._trials_loaded_indices):
-                    self.dataset_trials_filtered[trial_num] = self.load_trial_filter_step(
-                        trial_num, self.load_trial_dataset_step(trial_num), loaded_num=num)
+                    self.dataset_trials_filtered[
+                        trial_num] = self.load_trial_filter_step(
+                        trial_num, self.load_trial_dataset_step(trial_num),
+                        loaded_num=num)
+                if num % 7 == 0:
+                    self.dataset_trials_filtered = list(
+                        dask.compute(*self.dataset_trials_filtered))
                 self.dataset_trials_filtered = list(
                     dask.compute(*self.dataset_trials_filtered))
             self.shape = [
@@ -795,20 +843,24 @@ class DataHandler:
             if self.dataset_params["crop_x"][1] == 0:
                 self.dataset_params["crop_x"][1] = self.shape[0]
                 self.dataset_params["crop_y"][1] = self.shape[1]
-            if auto_crop:
+            if self.auto_crop:
                 crop = [[max([x[0][0] for x in self.suggested_crops]),
                          -max([x[0][1] for x in self.suggested_crops])],
                         [max([x[1][0] for x in self.suggested_crops]),
                          -max([x[1][1] for x in self.suggested_crops])]]
-                self.dataset_params["crop_x"][0] = self.dataset_params["crop_x"][0] + \
-                                                   crop[0][0]
-                self.dataset_params["crop_x"][1] = self.dataset_params["crop_x"][1] + \
-                                                   crop[0][1]
-                self.dataset_params["crop_y"][0] = self.dataset_params["crop_y"][0] + \
-                                                   crop[1][0]
-                self.dataset_params["crop_y"][1] = self.dataset_params["crop_y"][1] + \
-                                                   crop[1][1]
 
+                self.dataset_params["crop_x"][0] = 0 + \
+                                                   crop[0][0]
+                self.dataset_params["crop_x"][1] = self.total_size[0] + \
+                                                   crop[0][1]
+                self.dataset_params["crop_y"][0] = 0 + \
+                                                   crop[1][0]
+                self.dataset_params["crop_y"][1] = self.total_size[1] + \
+                                                   crop[1][1]
+                if crop[0][1] == 0:
+                    crop[0][1] = self.total_size[0]
+                if crop[1][1] == 0:
+                    crop[1][1] = self.total_size[1]
                 for trial_num in self._trials_loaded_indices:
                     self.dataset_trials_filtered[trial_num] = \
                         self.dataset_trials_filtered[trial_num][
@@ -819,9 +871,9 @@ class DataHandler:
                     self.max_images[trial_num] = self.max_images[trial_num][
                                                  crop[0][0]:crop[0][1],
                                                  crop[1][0]:crop[1][1]]
-                    self.temporal_correlation_images[trial_num] = \
-                    self.temporal_correlation_images[trial_num][
-                    crop[0][0]:crop[0][1], crop[1][0]:crop[1][1]]
+                    # self.temporal_correlation_images[trial_num] = \
+                    #     self.temporal_correlation_images[trial_num][
+                    #     crop[0][0]:crop[0][1], crop[1][0]:crop[1][1]]
                     if self.filter_params["pca"]:
                         self.pca_decomp[trial_num] = self.pca_decomp[trial_num][
                                                      :, crop[0][0]:crop[0][1],
@@ -883,6 +935,7 @@ class DataHandler:
     def real_trials(self):
         return not (self.dataset_params["single_file_mode"] or self.dataset_params[
             "trial_split"] or len(self.trials_loaded) == 1)
+
     def load_data(self):
         self.update_trial_list()
         self.dataset_trials_filtered = [False] * len(self.trials_all)
@@ -929,6 +982,7 @@ class DataHandler:
         if self.dataset_params["trial_split"] and self.dataset_params[
             "original_folder_trial_split"] != "":
             if self.dataset_params["single_file_mode"]:
+
                 z1 = zarr.open(
                     os.path.join(self.save_dir_path, "temp_files/dataset.zarr"),
                     mode="r")
@@ -937,10 +991,10 @@ class DataHandler:
                                                                      "trial_length"]))]
             else:
                 self.trials_loaded = [str(x) for x in range(ceil(len(os.listdir(
-                os.path.join(self.dataset_params["dataset_folder_path"],
-                             self.dataset_params["original_folder_trial_split"]))) /
-                                                             self.dataset_params[
-                                                                 "trial_length"]))]
+                    os.path.join(self.dataset_params["dataset_folder_path"],
+                                 self.dataset_params["original_folder_trial_split"]))) /
+                                                                 self.dataset_params[
+                                                                     "trial_length"]))]
             self.trials_all = self.trials_loaded.copy()
             self.box_params["total_num_time_steps"] = len(self.trials_loaded)
         elif self.dataset_params["original_folder_trial_split"] != "":
@@ -971,8 +1025,9 @@ class DataHandler:
                        "total_num_spatial_boxes"], "Please make sure Number of Spatial Boxes is a square number"
             try:
                 self.calculate_filters(progress_signal=progress_signal)
-                eigen_need_recalc = self.global_params["need_recalc_eigen_params"] or self.global_params[
-                    "need_recalc_box_params"]
+                eigen_need_recalc = self.global_params["need_recalc_eigen_params"] or \
+                                    self.global_params[
+                                        "need_recalc_box_params"]
                 self.global_params["need_recalc_eigen_params"] = False
                 self.global_params[
                     "need_recalc_roi_extraction_params"] = False
@@ -1040,7 +1095,7 @@ class DataHandler:
                                          roi_size_max=self.roi_extraction_params[
                                              "roi_size_max"],
                                          pca=self.filter_params["pca"],
-                                         pca_data= self.pca_decomp if self.filter_params[
+                                         pca_data=self.pca_decomp if self.filter_params[
                                              "pca"] else False,
                                          progress_signal=progress_signal)
                 self.box_params_processed = temp_params
@@ -1087,35 +1142,62 @@ class DataHandler:
                 [self.shape[0] * self.shape[1]])
             roi_edge[roi] = 255
             edge_roi_image += feature.canny(np.reshape(roi_edge,
-                                                  [self.shape[0],
-                                                   self.shape[1]]))
+                                                       [self.shape[0],
+                                                        self.shape[1]]))
 
         edge_roi_image[edge_roi_image > 255] = 255
         self.edge_roi_image_flat = np.reshape(edge_roi_image, [-1, 1]) * 255
         self.pixel_with_rois_color = np.reshape(self.pixel_with_rois_color_flat,
                                                 [self.shape[0],
                                                  self.shape[1], 3])
+
         try:
             self.eigen_norm_image = np.asarray(Image.open(
                 os.path.join(self.save_dir_path,
                              "embedding_norm_images/embedding_norm_image.png")))
         except:
             print("Can't generate eigen Norm image please try again")
-        self.roi_time_trace_need_update = []
-        for _ in range(len(self.rois)):
-            self.roi_time_trace_need_update.append(False)
+
+
 
     def calculate_time_traces(self, report_progress=None):
         """
         Calculates the time traces for every roi in self.rois
         """
-
-        self.time_traces = []
+        self.neuropil_pixels = calculate_nueropil(image_shape=self.shape,
+                                                  roi_list=self.rois,
+                                                  roi_mask_flat=self.pixel_with_rois_flat,
+                                                  min_pixels=100)  # self.time_trace_params["min_neuropil_pixels"])
+        self.neuropil_image_display = np.zeros(
+            [self.shape[0] * self.shape[1]])
+        for neurolpil in self.neuropil_pixels:
+            self.neuropil_image_display[neurolpil] = 255
+        self.neuropil_image_display = np.reshape(
+            np.dstack([self.neuropil_image_display, np.zeros(
+                [self.shape[0] * self.shape[1]]),
+                       (self.pixel_with_rois_flat > 0) * 255]),
+            [self.shape[0] * self.shape[1], 3])
+        self.roi_time_trace_need_update = []
         for _ in range(len(self.rois)):
-            self.time_traces.append([])
-            for _ in range(len(self.trials_all)):
-                self.time_traces[-1].append(False)
+            self.roi_time_trace_need_update.append(False)
+        self.time_traces = {x: [] for x in
+                            list(DataHandler.time_trace_possibilities_functions)}
+        for x in self.time_traces.keys():
+            for _ in range(len(self.rois)):
+                self.time_traces[x].append([])
+                for _ in range(len(self.trials_all)):
+                    self.time_traces[x][-1].append(False)
         calc_list = []
+        roi_time_traces_by_pixel = []
+        for _ in range(len(self.rois)):
+            roi_time_traces_by_pixel.append([])
+            for _ in range(len(self.trials_all)):
+                roi_time_traces_by_pixel[-1].append(False)
+        roi_neuropil_traces_by_pixel = []
+        for _ in range(len(self.rois)):
+            roi_neuropil_traces_by_pixel.append([])
+            for _ in range(len(self.trials_all)):
+                roi_neuropil_traces_by_pixel[-1].append(False)
         for trial_num in self.trials_loaded_time_trace_indices:
             data = self.load_trial_dataset_step(trial_num).compute()
             data_2d = reshape_to_2d_over_time(data[:])
@@ -1131,76 +1213,103 @@ class DataHandler:
             #         self.dataset_trials_filtered[trial_num])[:]
             calc_list = []
             for roi in range(len(self.rois)):
-                calc_list.append(
-                    (delayed)(
-                        self.calculate_time_trace(roi + 1, trial_num, data_2d=data_2d)))
-            dask.compute(*calc_list)
+                roi_time_traces_by_pixel[roi][trial_num] = data_2d[self.rois[roi]]
+                roi_neuropil_traces_by_pixel[roi][trial_num] = data_2d[
+                    self.neuropil_pixels[roi]]
             if report_progress is not None:
                 printProgressBar(self.trials_loaded_time_trace_indices.index(trial_num),
-                                 total=len(self.trials_loaded_time_trace_indices) + 2,
+                                 total=len(
+                                     self.trials_loaded_time_trace_indices) + len(
+                                     self.rois) + 2,
                                  prefix="Time Trace Calculation Progress:",
                                  suffix="Complete", progress_signal=report_progress)
         if not self.real_trials:
-            for roi_num in range(len(self.time_traces)):
-                self.time_traces[roi_num] = [np.hstack(
-                    [self.time_traces[roi_num][x] for x in
-                     self.trials_loaded_time_trace_indices])]
-                if self.time_trace_params["time_trace_type"] == "DeltaF Over F":
-                    self.time_traces[roi_num] = [
-                        calculateDeltaFOverF(0, self.time_traces[roi_num][0],
-                                             denoise=self.time_trace_params[
-                                                 "denoise"], given_mean=True)]
-                elif self.time_trace_params["denoise"]:
-                    self.time_traces[roi_num] = [waveletDenoise(
-                        self.time_traces[roi_num][0].reshape((1, -1))).reshape((-1))]
-
+            for roi_counter, roi_data, neuropil_data in zip(range(len(self.rois)),
+                                                            roi_time_traces_by_pixel,
+                                                            roi_neuropil_traces_by_pixel):
+                roi_data_combined = np.hstack(
+                    [roi_data[x] for x in self.trials_loaded_time_trace_indices])
+                neuropil_data_combined = np.hstack(
+                    [neuropil_data[x] for x in self.trials_loaded_time_trace_indices])
+                roi_data_denoised_combined = waveletDenoise(roi_data_combined)
+                for key in self.time_traces.keys():
+                    self.time_traces[key][roi_counter] = [
+                        DataHandler.time_trace_possibilities_functions[key](
+                            roi_data_combined, neuropil_data_combined,
+                            roi_data_denoised_combined)]
+                if report_progress is not None:
+                    printProgressBar(
+                        len(
+                            self.trials_loaded_time_trace_indices) + roi_counter + 1,
+                        total=len(
+                            self.trials_loaded_time_trace_indices) + len(self.rois) + 2,
+                        prefix="Time Trace Calculation Progress:",
+                        suffix="Complete", progress_signal=report_progress)
+        if self.real_trials:
+            for roi_counter, roi_data, neuropil_data in zip(range(len(self.rois)),
+                                                            roi_time_traces_by_pixel,
+                                                            roi_neuropil_traces_by_pixel):
+                roi_data_denoised = [waveletDenoise(x) if type(x) != bool else False for
+                                     x in roi_data]
+                for key in self.time_traces.keys():
+                    for trial_num in self.trials_loaded_time_trace_indices:
+                        self.time_traces[key][roi_counter][trial_num] = \
+                        DataHandler.time_trace_possibilities_functions[key](
+                            roi_data[trial_num], neuropil_data[trial_num],
+                            roi_data_denoised[trial_num])
+                if report_progress is not None:
+                    printProgressBar(
+                        len(
+                            self.trials_loaded_time_trace_indices) + roi_counter + 1,
+                        total=len(
+                            self.trials_loaded_time_trace_indices) + len(self.rois) + 2,
+                        prefix="Time Trace Calculation Progress:",
+                        suffix="Complete", progress_signal=report_progress)
         self.roi_time_trace_need_update = [False for _ in
                                            self.roi_time_trace_need_update]
 
         if os.path.isdir(self.save_dir_path):
             pickle_save(self.time_traces,
-                        "time_traces_{0}{1}".format(
-                            self.time_trace_params["time_trace_type"],
-                            "_denoised" if self.time_trace_params["denoise"] else ""),
+                        "time_traces",
                         output_directory=self.save_dir_path)
         self.rois_loaded = True
 
-    def calculate_time_trace(self, roi_num, trial_num=None, data_2d=None):
-        """
-        Calculates a time trace for a certain ROI and save to time trace list
-        Parameters
-        ----------
-        roi_num
-            roi to calculate for this starts at [1..number of rois]
-        trial_num
-            indice of trial in trials_all starts at [0, number of trials-1] if
-            none then calculates for all trials
-        """
-        trial_nums = [trial_num]
-        if trial_num == None:
-            trial_nums = self.trials_loaded_time_trace_indices
-        for trial_num in trial_nums:
-            roi = self.rois[roi_num - 1]
+    # def calculate_time_trace(self, roi_num, trial_num=None, data_2d=None):
+    #     """
+    #     Calculates a time trace for a certain ROI and save to time trace list
+    #     Parameters
+    #     ----------
+    #     roi_num
+    #         roi to calculate for this starts at [1..number of rois]
+    #     trial_num
+    #         indice of trial in trials_all starts at [0, number of trials-1] if
+    #         none then calculates for all trials
+    #     """
+    #     trial_nums = [trial_num]
+    #     if trial_num == None:
+    #         trial_nums = self.trials_loaded_time_trace_indices
+    #     for trial_num in trial_nums:
+    #         roi = self.rois[roi_num - 1]
+    #
+    #         if type(self.dataset_trials_filtered[
+    #                     trial_num]) == bool and data_2d == None:
+    #             self.dataset_trials_filtered[trial_num] = self.load_trial_filter_step(
+    #                 trial_num).compute()
+    #         if data_2d is None:
+    #             data_2d = reshape_to_2d_over_time(
+    #                 self.dataset_trials_filtered[trial_num])
+    #         if self.time_trace_params[
+    #             "time_trace_type"] == "DeltaF Over F" and self.real_trials:
+    #             time_trace = calculateDeltaFOverF(roi, data_2d,
+    #                                               denoise=self.time_trace_params[
+    #                                                   "denoise"] if self.real_trials else False)
+    #         else:
+    #             time_trace = calculateMeanTrace(roi, data_2d,
+    #                                             denoise=self.time_trace_params[
+    #                                                 "denoise"] if self.real_trials else False)
+    #         self.time_traces[roi_num - 1][trial_num] = time_trace
 
-            if type(self.dataset_trials_filtered[
-                        trial_num]) == bool and data_2d == None:
-                self.dataset_trials_filtered[trial_num] = self.load_trial_filter_step(
-                    trial_num).compute()
-            if data_2d is None:
-                data_2d = reshape_to_2d_over_time(
-                    self.dataset_trials_filtered[trial_num])
-            if self.time_trace_params[
-                "time_trace_type"] == "DeltaF Over F" and self.real_trials:
-                time_trace = calculateDeltaFOverF(roi, data_2d,
-                                                  denoise=self.time_trace_params[
-                                                      "denoise"] if self.real_trials else False)
-            else:
-                time_trace = calculateMeanTrace(roi, data_2d,
-                                                denoise=self.time_trace_params[
-                                                    "denoise"] if self.real_trials else False)
-            self.time_traces[roi_num - 1][trial_num] = time_trace
-
-    def get_time_trace(self, num, trial=None):
+    def get_time_trace(self, num, trial=None, trace_type="Mean Florescence"):
         """
         Returns the time trace for a certain roi over all currently selected trials
         Parameters
@@ -1213,25 +1322,27 @@ class DataHandler:
         np.ndarray of the time trace
         """
         if not self.real_trials:
-            if len(self.time_traces) > num - 1 and type(
-                    self.time_traces[num - 1][0]) != bool:
-                return self.time_traces[num - 1][0]
-            else:
+            try:
+                if len(self.time_traces[trace_type][num - 1]) == 1 and type(
+                        self.time_traces[trace_type][num - 1][0]) != bool:
+                    return self.time_traces[trace_type][num - 1][0]
+                else:
+                    return False
+
+            except IndexError:
                 return False
+
         if (trial == None):
             num = num - 1
             if self.real_trials:
                 output = np.ndarray(shape=(0))
                 for trial_num in self.trials_loaded_time_trace_indices:
-                    if type(self.time_traces[num][trial_num]) == bool:
-                        self.calculate_time_trace(num + 1, trial_num)
-                    output = np.hstack([output, self.time_traces[num][trial_num]])
+                    output = np.hstack(
+                        [output, self.time_traces[trace_type][num][trial_num]])
             else:
                 return self.time_traces[num]
         else:
             num = num - 1
-            if type(self.time_traces[num][trial]) == bool:
-                self.calculate_time_trace(num + 1, trial)
             output = self.time_traces[num][trial]
         return output
 
@@ -1351,15 +1462,15 @@ class DataHandler:
         pass
 
     def export(self):
-        temp_type = self.time_trace_params["time_trace_type"]
-        for time_type in ["Mean", "DeltaF Over F"]:
-            for denoise in [True, False]:
-                self.time_trace_params["denoise"] = denoise
-                self.time_trace_params["time_trace_type"] = time_type
-                self.calculate_time_traces()
-                if time_type == "Mean" and denoise:
-                    self.calculate_statistics()
-        self.time_trace_params["time_trace_type"] = temp_type
+        # temp_type = self.time_trace_params["time_trace_type"]
+        # for time_type in ["Mean", "DeltaF Over F"]:
+        #     for denoise in [True, False]:
+        #         self.time_trace_params["denoise"] = denoise
+        #         self.time_trace_params["time_trace_type"] = time_type
+        #         self.calculate_time_traces()
+        #         # if time_type == "Mean" and denoise:
+        #         #     self.calculate_statistics()
+        # self.time_trace_params["time_trace_type"] = temp_type
         self.save_rois(self.rois)
         roi_save_object = []
         spatial_box = SpatialBox(0, 1, image_shape=self.shape, spatial_overlap=0)
@@ -1407,6 +1518,7 @@ class DataHandler:
                         (self.shape[0], self.shape[1], 3)) / (
                      image.max() - image.min()) * 255).astype("uint8"))
         img.save(path)
+
     def delete_roi_vars(self):
         self.rois = []
         self.rois_loaded = False
