@@ -1,3 +1,4 @@
+from qtpy import QtCore
 from qtpy.QtWidgets import *
 
 from CIDAN.GUI.Inputs.Input import Input
@@ -10,16 +11,16 @@ class BoolInput(Input):
                          tool_tip, display_tool_tip)
 
         self.input_box = QCheckBox()
-        self.input_box.setMaximumWidth(40)
+        self.input_box.setMaximumWidth(40*((self.logicalDpiX() / 96.0-1)/2+1))
         self.input_box.setStyleSheet("""QCheckBox::indicator {
-     width: 25px;
-     height: 25px;
- }""")
+     width: %spx;
+     height: %spx; }QCheckBox{margin %spx;
+ }""" % (str(25*self.logicalDpiX() / 96.0),str(25*self.logicalDpiX() / 96.0),str(3*self.logicalDpiX() / 96.0)))
 
         self.input_box.setChecked(self.default_val)
         self.input_box.toggled.connect(self.on_change)
         self.input_box.setToolTip(self.tool_tip)
-        self.layout_h.addWidget(self.input_box)
+        self.layout_h.addWidget(self.input_box, alignment=QtCore.Qt.AlignRight)
 
     def current_state(self):
         return self.input_box.isChecked()
