@@ -5,6 +5,7 @@ import pyqtgraph as pg
 import qdarkstyle
 from qtpy.QtWidgets import *
 
+from CIDAN.GUI.Data_Interaction import DataHandler
 from CIDAN.GUI.Data_Interaction.ROIExtractionThread import ROIExtractionThread
 from CIDAN.GUI.Data_Interaction.TimeTraceCalculateThread import TimeTraceCalculateThread
 from CIDAN.GUI.ImageView.ROIPaintImageViewModule import ROIPaintImageViewModule
@@ -101,10 +102,10 @@ class ROIExtractionTab(Tab):
                               "Select an roi in the ROI list below")
         delete_roi.clicked.connect(
             lambda x: self.delete_roi(self.roi_list_module.current_selected_roi))
-
+        roi_modification_button_top_layout.addWidget(add_new_roi)
         roi_modification_button_top_layout.addWidget(add_to_roi)
         roi_modification_button_top_layout.addWidget(sub_to_roi)
-        roi_modification_button_top_layout.addWidget(add_new_roi)
+
         roi_modification_button_top_layout.addWidget(delete_roi)
         add_to_roi.setStyleSheet("QWidget {border: 0px solid #32414B;}")
         sub_to_roi.setStyleSheet("QWidget {border: 0px solid #32414B;}")
@@ -146,7 +147,7 @@ class ROIExtractionTab(Tab):
 
         painter_layout = QVBoxLayout()
         painter_widget.setLayout(painter_layout)
-        label = QLabel(text="Mask Brush: ")
+        label = QLabel(text="Mask Brush (green): ")
         label.setStyleSheet("QWidget {border: 0px solid #32414B;}")
 
         painter_layout_sub_1 = QHBoxLayout()
@@ -248,14 +249,12 @@ class ROIExtractionTab(Tab):
         time_trace_settings_layout.setContentsMargins(0, 0, 0, 0)
         time_trace_settings.setLayout(time_trace_settings_layout)
         self.time_trace_type = OptionInput("Time Trace Type", "",
-                                           lambda x, y: x + y,
+                                           lambda x, y: self.deselectRoiTime(),
                                            default_index=0,
                                            tool_tip="Select way to calculate time trace,"
                                                     " \ncheck github for more details",
-                                           val_list=["Mean Florescence Denoised",
-                                                     "Mean Florescence",
-                                                     "DeltaF Over F Denoised",
-                                                     "DeltaF Over F"])
+                                           val_list=list(
+                                               self.data_handler.time_trace_possibilities_functions.keys()))
         time_trace_settings_layout.addWidget(self.time_trace_type,
                                              stretch=1)
         # A list widget to select what trials to calculate/display time traces for
@@ -381,11 +380,11 @@ class ROIExtractionTab(Tab):
             self.data_handler.rois.append(
                 temp_roi)
             self.data_handler.gen_roi_display_variables()
-            self.data_handler.time_traces.append([])
-            for _ in range(len(self.data_handler.trials_all)):
-                self.data_handler.time_traces[-1].append(False)
+            # self.data_handler.time_traces.append([])
+            # for _ in range(len(self.data_handler.trials_all)):
+            #     self.data_handler.time_traces[-1].append(False)
             self.data_handler.roi_time_trace_need_update.append(True)
-            self.data_handler.time_traces.append([np.zeros(50)])
+            # self.data_handler.time_traces.append([np.zeros(50)])
             self.image_view.clearPixelSelection()
             self.update_roi(False)
             self.roi_list_module.set_list_items(self.data_handler.rois)
@@ -418,7 +417,9 @@ class ROIExtractionTab(Tab):
                 self.main_widget.console.updateText("Deleting ROI #%s" % str(roi_num + 1))
                 self.data_handler.rois.pop(roi_num)
                 self.data_handler.gen_roi_display_variables()
-                self.data_handler.time_traces.pop(roi_num)
+                for x in self.data_handler.time_traces.keys():
+                    self.data_handler.time_traces[x].pop(roi_num)
+
                 self.data_handler.roi_time_trace_need_update.pop(roi_num)
                 self.update_roi(False)
                 self.roi_list_module.set_list_items(self.data_handler.rois)
@@ -531,8 +532,11 @@ class ROIExtractionTab(Tab):
                             "Some time traces are out of date, please recalculate",
                             warning=True)
                     pen = pg.mkPen(color=color_roi, width=3)
-                    self.time_plot.plot(
-                        self.main_widget.data_handler.get_time_trace(num),
+                    time_trace = self.main_widget.data_handler.get_time_trace(num,
+                                                                              trace_type=self.time_trace_type.current_state())
+                    if type(time_trace) == bool:
+                        return
+                    self.time_plot.plot(time_trace,
                         pen=pen)
                     self.time_plot.enableAutoRange(axis=0)
             except AttributeError:
@@ -556,7 +560,9 @@ class ROIExtractionTab(Tab):
 
                         pen = pg.mkPen(color=color_roi, width=3)
                         self.time_plot.plot(
-                            self.main_widget.data_handler.get_time_trace(num2), pen=pen)
+                            self.main_widget.data_handler.get_time_trace(num2,
+                                                                         trace_type=self.time_trace_type.current_state()),
+                            pen=pen)
             except AttributeError:
                 print("No ROIs have been generated yet")
 
@@ -568,16 +574,10 @@ class ROIExtractionTab(Tab):
             self.deselectRoiTime()
             self.main_widget.tabs[2].updateTab()
         if self.main_widget.checkThreadRunning():
-            curr_type = "Mean" if "Mean" in self.time_trace_type.current_state() \
-                else "DeltaF Over F"
-            denoise = "Denoised" in self.time_trace_type.current_state()
-            if (self.data_handler.time_trace_params[
-                "time_trace_type"] != curr_type or self.data_handler.time_trace_params[
-                    "denoise"] != denoise) or any(
+
+            if any(
                 self.data_handler.roi_time_trace_need_update):
-                self.data_handler.time_trace_params[
-                    "time_trace_type"] = curr_type
-                self.data_handler.time_trace_params["denoise"] = denoise
+
                 # self.data_handler.calculate_time_traces()
                 self.time_trace_thread.runThread(end_func)
 
