@@ -3,7 +3,8 @@ import numpy as np
 from CIDAN.TimeTrace.mean import calculateMeanTrace
 
 
-def calculateDeltaFOverF(roi, data, denoise=True, given_mean=False):
+def calculateDeltaFOverF(roi_data, neuropil, roi_denoised_data, denoise=True,
+                         sub_neuropil=False):
     """
     Calcualtes the DeltaF Over F time trace for a given roi and data
     Parameters
@@ -18,10 +19,10 @@ def calculateDeltaFOverF(roi, data, denoise=True, given_mean=False):
     -------
     A 1d nd array with the time trace for the ROI
     """
-    if not given_mean:
-        time_trace = calculateMeanTrace(roi, data, denoise)
-    else:
-        time_trace = data
+
+    time_trace = calculateMeanTrace(roi_data, neuropil, roi_denoised_data, denoise,
+                                    sub_neuropil)
+
     bottom_10_number = np.percentile(time_trace, 10)
 
     bottom_10_frames = time_trace[time_trace < bottom_10_number]
